{
  "type": "record",
  "name": "DataProcessInstanceKey",
  "namespace": "com.linkedin.pegasus2avro.metadata.key",
  "doc": "Key for an Asset DataProcessInstance",
  "fields": [
    {
      "name": "id",
      "type": "string",
      "doc": "A unique id for the DataProcessInstance . Should be separate from the name used for displaying a DataProcessInstance."
    }
  ],
  "Aspect": {
    "name": "dataProcessInstanceKey"
  }
}